@@ -5,45 +5,45 @@ The full license is in the file LICENSE, distributed with this software.
 
 Copyright (C) Jun Zhu. All rights reserved.
 """
-import os
+from pathlib import Path
 import shutil
+from typing import Union
 import weakref
 
 
-class TempSimulationDirectory(object):
+class TempSimulationDirectory:
     """Create temporary directories to hold simulation files."""
 
-    def __init__(self, folder, *, delete_old=False):
+    def __init__(self, name: Union[str, Path]) -> None:
         """Initialization.
 
-        :param str folder: full path of the temporary directory.
-        :param bool delete_old: True for deleting the folder if it already
-            exists.
+        :param name: full path of the temporary directory.
+
+        :raises FileExistsError: If the directory already exists.
         """
-        if delete_old and os.path.isdir(folder):
-            shutil.rmtree(folder)
+        name = Path(name)
 
         # owner can read, write and execute
         # Raise FileExistsError if the directory already exists and
         # 'self._cleanup' will not be registered.
-        os.mkdir(folder, mode=0o700)
-        self._name = folder
+        name.mkdir(mode=0o700)
 
-        self._finalizer = weakref.finalize(self, self._cleanup, self._name)
+        self._name = name
+        self._finalizer = weakref.finalize(self, self._cleanup, name)
 
     def __repr__(self):
         return f"<{self.__class__.__name__} {self._name}>"
 
-    def __enter__(self):
+    def __enter__(self) -> Path:
         return self._name
 
     def __exit__(self, exc, value, tb):
         self.cleanup()
 
     @classmethod
-    def _cleanup(cls, name):
+    def _cleanup(cls, name: Path) -> None:
         shutil.rmtree(name)
 
-    def cleanup(self):
+    def cleanup(self) -> None:
         if self._finalizer.detach() is not None:
             shutil.rmtree(self._name)
