@@ -1,6 +1,6 @@
-import unittest
+from pathlib import Path
 import tempfile
-import pathlib
+import unittest
 
 import numpy as np
 import pandas as pd
@@ -9,6 +9,7 @@ from liso import EuXFELInterface, Phasespace
 from liso.experiment import doocs_channels as dc
 from liso.io import ExpWriter, SimWriter, open_run, open_sim
 from liso.io.reader import ExpDataCollection, SimDataCollection
+from liso.utils import changed_cwd
 
 
 class TestSimReader(unittest.TestCase):
@@ -24,19 +25,19 @@ class TestSimReader(unittest.TestCase):
         self._sim_ids_gt = np.arange(2 * self._file_size + self._chunk_size + 9) + self._file_size
         np.random.shuffle(self._sim_ids_gt)  # sim_id does not come in sequence
 
-    def testOpenSim(self):
+    def testOpenSim(self):  # pylint: disable=too-many-locals,too-many-statements
         chunk_size = self._chunk_size
         file_size = self._file_size
         n_particles = self._n_particles
         sim_ids_gt = self._sim_ids_gt
 
         with tempfile.TemporaryDirectory() as tmp_dir:
-            schema = (
-                {
+            schema = {
+                "control": {
                     "gun/gun_gradient": {"type": "<f4"},
                     "gun/gun_phase": {"type": "<f4"}
                 },
-                {
+                "phasespace": {
                     "gun/out1": {
                         "macroparticles": n_particles,
                         "type": "phasespace"
@@ -46,9 +47,11 @@ class TestSimReader(unittest.TestCase):
                         "type": "phasespace"
                     }
                 }
-            )
+            }
+            path = Path(tmp_dir)
+            path.joinpath('s0001').mkdir()
 
-            with SimWriter(tmp_dir,
+            with SimWriter(path.joinpath('s0001'),
                            schema=schema,
                            chunk_size=chunk_size,
                            max_events_per_file=file_size) as writer:
@@ -62,16 +65,18 @@ class TestSimReader(unittest.TestCase):
                         pd.DataFrame(np.ones((n_particles, 7)) * i * 0.1,
                                      columns=['x', 'px', 'y', 'py', 'z', 'pz', 't']), 1.0)
 
-                    writer.write(sid,
-                                 {'gun/gun_gradient': 10 * i, 'gun/gun_phase': 20 * i},
-                                 {'gun/out1': ps1, 'gun/out2': ps2})
-
-            path = pathlib.Path(tmp_dir)
-            files = sorted([f.name for f in path.iterdir()])
+                    writer.write(sid, {
+                        'control': {
+                            'gun/gun_gradient': 10 * i, 'gun/gun_phase': 20 * i
+                        },
+                        'phasespace': {
+                            'gun/out1': ps1, 'gun/out2': ps2
+                        }
+                    })
 
             with self.subTest("Test opening a single file"):
-                for i, file in enumerate(files):
-                    data = open_sim(path.joinpath(file))
+                for i, file in enumerate(sorted(path.joinpath('s0001').iterdir())):
+                    data = open_sim(file)
                     self.assertIsInstance(data, SimDataCollection)
                     data.info()
                     self._check_sim_metadata(data, i)
@@ -79,22 +84,26 @@ class TestSimReader(unittest.TestCase):
                     self._check_sim_iterate_over_data(data, i)
                     self._check_sim_access_data(data, i)
 
-            with self.subTest("Test opening a folder"):
-                data = open_sim(tmp_dir)
+            with self.subTest("Test opening a folder with absolute path"):
+                data = open_sim(path.joinpath("s0001"))
                 self._check_sim_metadata(data)
                 self._check_sim_get_control(data)
                 self._check_sim_iterate_over_data(data)
                 self._check_sim_access_data(data)
 
+            with self.subTest("Test opening a folder with relative path"):
+                with changed_cwd(tmp_dir):
+                    data = open_sim("s0001")
+
             with self.subTest("Test control channel data"):
                 with self.assertRaisesRegex(KeyError, 'No data was found for channel'):
                     data.channel('gun/random')
 
                 item = data.channel('gun/gun_phase')
                 with self.assertRaises(KeyError):
-                    data[min(self._sim_ids_gt) - 1]
+                    _ = data[min(self._sim_ids_gt) - 1]
                 with self.assertRaises(KeyError):
-                    data[max(self._sim_ids_gt) + 1]
+                    _ = data[max(self._sim_ids_gt) + 1]
 
                 idx = 9
                 self.assertEqual(idx * 20, item[self._sim_ids_gt[idx]])
@@ -156,7 +165,7 @@ class TestSimReader(unittest.TestCase):
             np.testing.assert_array_equal(self._sim_ids_gt, control_data.index)
 
             # test sorted
-            sorted_control_data = data.get_controls(sorted=True)
+            sorted_control_data = data.get_controls(ordered=True)
             np.testing.assert_array_equal(sorted(self._sim_ids_gt),
                                           sorted_control_data.index)
         elif i == 2:
@@ -180,11 +189,11 @@ class TestSimReader(unittest.TestCase):
 
     def _check_sim_iterate_over_data(self, data, i=None):
         with self.assertRaises(KeyError):
-            data[min(self._sim_ids_gt) - 1]
+            _ = data[min(self._sim_ids_gt) - 1]
         with self.assertRaises(KeyError):
-            data[max(self._sim_ids_gt) + 1]
+            _ = data[max(self._sim_ids_gt) + 1]
 
-        for idx, (sid, sim) in enumerate(data):
+        for idx, (_, sim) in enumerate(data):
             if i is not None:
                 idx += i * self._file_size
             self.assertSetEqual({
@@ -229,13 +238,13 @@ class TestSimReader(unittest.TestCase):
 class TestExpReader(unittest.TestCase):
     def setUp(self):
         m = EuXFELInterface()
-        m.add_control_channel(dc.FLOAT32, "XFEL.A/B/C/D")
-        m.add_control_channel(dc.FLOAT32, "XFEL.A/B/C/E")
-        m.add_control_channel(dc.BOOL, "XFEL.A/B/C/F")
+        m.add_control_channel("XFEL.A/B/C/D", dc.FLOAT32)
+        m.add_control_channel("XFEL.A/B/C/E", dc.FLOAT32)
+        m.add_control_channel("XFEL.A/B/C/F", dc.BOOL)
         self._s1 = (3, 4)
         self._s2 = (6, 5)
-        m.add_diagnostic_channel(dc.IMAGE, "XFEL.H/I/J/K", shape=self._s1, dtype='uint16')
-        m.add_diagnostic_channel(dc.IMAGE, "XFEL.H/I/J/L", shape=self._s2, dtype='float32')
+        m.add_diagnostic_channel("XFEL.H/I/J/K", dc.ARRAY, shape=self._s1, dtype='uint16')
+        m.add_diagnostic_channel("XFEL.H/I/J/L", dc.ARRAY, shape=self._s2, dtype='float32')
         self._schema = m.schema
 
         self._orig_image_chunk = ExpWriter._IMAGE_CHUNK
@@ -262,12 +271,15 @@ class TestExpReader(unittest.TestCase):
                            max_events_per_file=file_size) as writer:
 
                 for i, pid in enumerate(pulse_ids_gt):
-                    writer.write(
-                        pid,
-                        {"XFEL.A/B/C/D": 10 * i, "XFEL.A/B/C/E": 0.1 * i},
-                        {"XFEL.H/I/J/K": np.ones(s1, dtype=np.uint16),
-                         "XFEL.H/I/J/L": np.ones(s2, dtype=np.float32)}
-                    )
+                    writer.write(pid, {
+                        'control': {
+                            "XFEL.A/B/C/D": 10 * i, "XFEL.A/B/C/E": 0.1 * i
+                        },
+                        'diagnostic': {
+                            "XFEL.H/I/J/K": np.ones(s1, dtype=np.uint16),
+                            "XFEL.H/I/J/L": np.ones(s2, dtype=np.float32)
+                        }
+                    })
 
             data = open_run(tmp_dir)
             self.assertIsInstance(data, ExpDataCollection)
@@ -304,7 +316,7 @@ class TestExpReader(unittest.TestCase):
             with self.subTest("Test reading a single control data channel"):
                 item = data.channel('XFEL.A/B/C/D')
                 with self.assertRaises(KeyError):
-                    item[2]
+                    _ = item[2]
                 self.assertEqual(30., item[pulse_ids_gt[3]])
                 self.assertEqual(30., item.from_id(pulse_ids_gt[3]))
                 self.assertEqual(10., item.from_index(1))
