@@ -1,7 +1,8 @@
-import unittest
-import tempfile
-import pathlib
+# pylint: disable=no-member
 from datetime import datetime
+from pathlib import Path
+import tempfile
+import unittest
 
 import h5py
 import pandas as pd
@@ -10,13 +11,21 @@ import numpy as np
 from liso import EuXFELInterface
 from liso import doocs_channels as dc
 from liso.io import ExpWriter, SimWriter
+from liso.io.file_access import _IS_H5PY_VERSION_2
 from liso.proc import Phasespace
 
 
 def _check_create_update_date(fp):
-    create_date = datetime.fromisoformat(fp['METADATA/createDate'][()])
+    if _IS_H5PY_VERSION_2:
+        create_date = datetime.fromisoformat(fp['METADATA/createDate'][()])
+    else:
+        create_date = datetime.fromisoformat(fp['METADATA/createDate'].asstr()[()])
     assert 0 < (datetime.now() - create_date).total_seconds() < 1.0
-    update_date = datetime.fromisoformat(fp['METADATA/updateDate'][()])
+
+    if _IS_H5PY_VERSION_2:
+        update_date = datetime.fromisoformat(fp['METADATA/updateDate'][()])
+    else:
+        update_date = datetime.fromisoformat(fp['METADATA/updateDate'].asstr()[()])
     assert 0 < (datetime.now() - update_date).total_seconds() < 1.0
     assert (update_date - create_date).total_seconds() > 0
 
@@ -38,18 +47,18 @@ class TestSimWriter(unittest.TestCase):
         sim_ids_gt = self._sim_ids_gt
 
         with tempfile.TemporaryDirectory() as tmp_dir:
-            schema = (
-                {
+            schema = {
+                "control": {
                     "gun/gun_gradient": {"type": "<f4"},
                     "gun/gun_phase": {"type": "<f4"}
                 },
-                {
+                "phasespace": {
                     "gun/out": {
                         "macroparticles": n_particles,
                         "type": "phasespace"
                     }
                 }
-            )
+            }
 
             with self.subTest("Test invalid input in writer"):
                 with self.assertRaisesRegex(ValueError, "cannot be smaller than chunk_size"):
@@ -68,22 +77,32 @@ class TestSimWriter(unittest.TestCase):
                                           't']), 1.0)
 
                 for i, sid in enumerate(sim_ids_gt):
-                    writer.write(sid,
-                                 {'gun/gun_gradient': 10 * i, 'gun/gun_phase': 0.1 * i},
-                                 {'gun/out': ps})
+                    writer.write(sid, {
+                        'control': {
+                            'gun/gun_gradient': 10 * i, 'gun/gun_phase': 0.1 * i
+                        },
+                        'phasespace': {
+                            'gun/out': ps
+                        }
+                    })
 
-            path = pathlib.Path(tmp_dir)
+            path = Path(tmp_dir)
             files = sorted([f.name for f in path.iterdir()])
             self.assertListEqual(
-                [f"SIM-G01-S00000{i}.hdf5" for i in range(3)], files
+                [f"SIM-{path.name.upper()}-G01-S00000{i}.hdf5" for i in range(3)], files
             )
 
             with self.subTest("Initialize writer when hdf5 file already exits"):
                 with SimWriter(tmp_dir, schema=schema) as writer:
                     with self.assertRaises(OSError):
-                        writer.write(0,
-                                     {'gun/gun_gradient': 0, 'gun/gun_phase': 0},
-                                     {'gun/out': ps})
+                        writer.write(0, {
+                            'control': {
+                                'gun/gun_gradient': 0, 'gun/gun_phase': 0
+                            },
+                            'phasespace': {
+                                'gun/out': ps
+                            }
+                        })
 
             with self.subTest("Test data in the file"):
                 self._check_data_files(path, files)
@@ -94,9 +113,14 @@ class TestSimWriter(unittest.TestCase):
                     ps = Phasespace(pd.DataFrame(
                         np.ones((n_particles + 1, 7)),
                         columns=['x', 'px', 'y', 'py', 'z', 'pz', 't']), 1.0)
-                    writer.write(0,
-                                {'gun/gun_gradient': 1, 'gun/gun_phase': 2},
-                                {'gun/out': ps})
+                    writer.write(0, {
+                        'control': {
+                            'gun/gun_gradient': 1, 'gun/gun_phase': 2
+                        },
+                        'phasespace': {
+                            'gun/out': ps
+                        }
+                    })
 
                     for col in ['x', 'y', 'z', 'px', 'py', 'pz', 't']:
                         self.assertFalse(
@@ -112,10 +136,16 @@ class TestSimWriter(unittest.TestCase):
             with h5py.File(path.joinpath(file), 'r') as fp:
                 _check_create_update_date(fp)
 
-                self.assertSetEqual({'gun/gun_gradient', 'gun/gun_phase'},
-                                    set(fp['METADATA/controlChannel']))
-                self.assertSetEqual({'gun/out'},
-                                    set(fp['METADATA/phasespaceChannel']))
+                if _IS_H5PY_VERSION_2:
+                    self.assertSetEqual({'gun/gun_gradient', 'gun/gun_phase'},
+                                        set(fp['METADATA/controlChannel']))
+                    self.assertSetEqual({'gun/out'},
+                                        set(fp['METADATA/phasespaceChannel']))
+                else:
+                    self.assertSetEqual({b'gun/gun_gradient', b'gun/gun_phase'},
+                                        set(fp['METADATA/controlChannel']))
+                    self.assertSetEqual({b'gun/out'},
+                                        set(fp['METADATA/phasespaceChannel']))
 
                 if i == 2:
                     np.testing.assert_array_equal(
@@ -160,13 +190,13 @@ class TestSimWriter(unittest.TestCase):
 class TestExpWriter(unittest.TestCase):
     def setUp(self):
         m = EuXFELInterface()
-        m.add_control_channel(dc.FLOAT64, "XFEL.A/B/C/D")
-        m.add_control_channel(dc.FLOAT32, "XFEL.A/B/C/E")
+        m.add_control_channel("XFEL.A/B/C/D", dc.FLOAT64)
+        m.add_control_channel("XFEL.A/B/C/E", dc.FLOAT32)
 
         self._s1 = (4, 4)
         self._s2 = (5, 6)
-        m.add_diagnostic_channel(dc.IMAGE, "XFEL.H/I/J/K", shape=self._s1, dtype='uint16')
-        m.add_diagnostic_channel(dc.IMAGE, "XFEL.H/I/J/L", shape=self._s2, dtype='float32')
+        m.add_diagnostic_channel("XFEL.H/I/J/K", dc.ARRAY, shape=self._s1, dtype='uint16')
+        m.add_diagnostic_channel("XFEL.H/I/J/L", dc.ARRAY, shape=self._s2, dtype='float32')
         self._schema = m.schema
 
         self._orig_image_chunk = ExpWriter._IMAGE_CHUNK
@@ -194,14 +224,17 @@ class TestExpWriter(unittest.TestCase):
                            max_events_per_file=file_size) as writer:
 
                 for i, pid in enumerate(pulse_ids_gt):
-                    writer.write(
-                        pid,
-                        {"XFEL.A/B/C/D": 10 * i, "XFEL.A/B/C/E": 0.1 * i},
-                        {"XFEL.H/I/J/K": np.ones(s1, dtype=np.uint16),
-                         "XFEL.H/I/J/L": np.ones(s2, dtype=np.float32)}
-                    )
+                    writer.write(pid, {
+                        'control': {
+                            "XFEL.A/B/C/D": 10 * i, "XFEL.A/B/C/E": 0.1 * i
+                        },
+                        'diagnostic': {
+                            "XFEL.H/I/J/K": np.ones(s1, dtype=np.uint16),
+                            "XFEL.H/I/J/L": np.ones(s2, dtype=np.float32)
+                        }
+                    })
 
-            path = pathlib.Path(tmp_dir)
+            path = Path(tmp_dir)
             files = sorted([f.name for f in path.iterdir()])
             self.assertListEqual(
                 [f"RAW-{path.name.upper()}-G11-S00000{i}.hdf5" for i in range(3)], files
@@ -219,10 +252,16 @@ class TestExpWriter(unittest.TestCase):
             with h5py.File(path.joinpath(file), 'r') as fp:
                 _check_create_update_date(fp)
 
-                self.assertSetEqual(
-                    {"XFEL.A/B/C/D", "XFEL.A/B/C/E"}, set(fp['METADATA/controlChannel']))
-                self.assertSetEqual(
-                    {"XFEL.H/I/J/K", "XFEL.H/I/J/L"}, set(fp['METADATA/diagnosticChannel']))
+                if _IS_H5PY_VERSION_2:
+                    self.assertSetEqual({"XFEL.A/B/C/D", "XFEL.A/B/C/E"},
+                                        set(fp['METADATA/controlChannel']))
+                    self.assertSetEqual({"XFEL.H/I/J/K", "XFEL.H/I/J/L"},
+                                        set(fp['METADATA/diagnosticChannel']))
+                else:
+                    self.assertSetEqual({b"XFEL.A/B/C/D", b"XFEL.A/B/C/E"},
+                                        set(fp['METADATA/controlChannel']))
+                    self.assertSetEqual({b"XFEL.H/I/J/K", b"XFEL.H/I/J/L"},
+                                        set(fp['METADATA/diagnosticChannel']))
 
                 if i == 2:
                     np.testing.assert_array_equal(
