@@ -1,3 +1,10 @@
+"""
+Distributed under the terms of the GNU General Public License v3.0.
+
+The full license is in the file LICENSE, distributed with this software.
+
+Copyright (C) Jun Zhu. All rights reserved.
+"""
 import logging
 
 from .config import config
@@ -5,9 +12,10 @@ from .config import config
 
 def create_logger():
     """General logger."""
-    logger = logging.getLogger("LISO")
+    lg = logging.getLogger("LISO")
 
-    fh = logging.FileHandler(config['DEFAULT']['LOG_FILE'], mode='w')
+    fh = logging.FileHandler(config['DEFAULT']['LOG_FILE'],
+                             mode='w', delay=True)
     formatter = logging.Formatter('%(asctime)s - %(levelname)s - %(message)s')
     fh.setFormatter(formatter)
 
@@ -15,10 +23,10 @@ def create_logger():
     formatter = logging.Formatter('%(levelname)s - %(message)s')
     ch.setFormatter(formatter)
 
-    logger.addHandler(fh)
-    logger.addHandler(ch)
+    lg.addHandler(fh)
+    lg.addHandler(ch)
 
-    return logger
+    return lg
 
 
 logger = create_logger()
@@ -27,16 +35,17 @@ logger.setLevel(logging.INFO)
 
 def create_opt_logger():
     """Logger for optimization information."""
-    logger = logging.getLogger("LISO-Opt")
-    logger.setLevel(logging.DEBUG)
+    lg = logging.getLogger("LISO-Opt")
+    lg.setLevel(logging.DEBUG)
 
-    fh = logging.FileHandler(config['DEFAULT']['OPT_LOG_FILE'], mode="w")
+    fh = logging.FileHandler(config['DEFAULT']['OPT_LOG_FILE'],
+                             mode="w", delay=True)
     formatter = logging.Formatter('%(asctime)s - %(message)s')
     fh.setFormatter(formatter)
 
-    logger.addHandler(fh)
+    lg.addHandler(fh)
 
-    return logger
+    return lg
 
 
 opt_logger = create_opt_logger()
