@@ -5,7 +5,9 @@ The full license is in the file LICENSE, distributed with this software.
 
 Copyright (C) Jun Zhu. All rights reserved.
 """
+import contextlib
 import functools
+import os
 from threading import Thread
 import time
 
@@ -36,7 +38,17 @@ def profiler(info, *, process_time=False):
             t0 = timer()
             result = f(*args, **kwargs)
             dt_ms = 1000 * (timer() - t0)
-            logger.info(f"Time spent on {info}: {dt_ms:.3f} ms")
+            logger.info("Time spent on %s: %.3f ms", info, dt_ms)
             return result
         return timed_f
     return wrap
+
+
+@contextlib.contextmanager
+def changed_cwd(dirname):
+    oldcwd = os.getcwd()
+    os.chdir(dirname)
+    try:
+        yield
+    finally:
+        os.chdir(oldcwd)
